#!/bin/csh

# This very simple csh script runs a MOBCAL job on the desired  job.mfj
# input file.  A temporary working subdirectory (.tmp.*) is created for
# cleanliness (e.g. so that large numbers of jobs can easily be run in the same
# working dir, each with their own working dir.
# The .mob  MOBCAL output file is then copied back to the
# original directory at the completion of the run.   A mobcal.in file
# is also created in each working dir, for which a random-ish seed is
# created and placed in  mobcal.in  as needed by the MOBCAL program.
#
# Look at the bottom of this script -- you will need to edit this 
# script corresponding to the name of your compiled MOBCAL executable
#

# Your path to the MOBCAL executables goes below

set path = ($path /home/mdb/WORKSHOP/STARTING_STRUCTURES_TEMPLATES_AND_PROGRAMS/programs_and_scripts)

echo ''

# Test for file

if (($#argv != 1) || ($#argv == 1 && $1 == "-h")) then
   echo "Usage:  runmobcal_n2.csh filename.mfj"
   echo ''
   exit
endif

if (-e ${argv[1]}) then


   set suffix = `echo $1 | sed 's/\./ /g' | awk '{print $NF}'`


   if ($suffix != "mfj") then
      echo "Your MOBCAL input file should end in a  .mfj  extension."
      echo "Goodbye."
      echo ''
      exit
   endif
else
   echo "Sorry, ${argv[1]} not found."
   echo "Goodbye."
   echo ''
   exit
endif



# Set some variables

set proc = $$
set workdir = `pwd`

set mfjfile = ${argv[1]}
set prefix = `echo $mfjfile | sed 's/\///' | sed 's/\// /g' | awk '{print $NF}' | sed 's/\./ /g' | awk '{print $1}'`

# Make a temporary hidden subdirectory for cleanliness & copy everything in

set tmpdir = ${workdir}/.tmp.${proc}.${prefix}
mkdir $tmpdir
wait
cp $mfjfile $tmpdir/$prefix
wait
echo $prefix >> $tmpdir/mobcal.in
echo "${prefix}.mob"  >> $tmpdir/mobcal.in


# Make up a quasi-random two-digit number for 'random' seed
shuf -i 11-99 -n 1 >> $tmpdir/mobcal.in
wait

# Run the job then copy output back up

cd $tmpdir

workshop_mobcal_iain_n2.exe
wait
cp ${tmpdir}/${prefix}.mob ${workdir}
cd $workdir
rm -rf $tmpdir
exit

